import * as Git from "./git";
export { Git };
/**
 * Storageして利用するリポジトリの情報
 */
export interface RepositoryConfig {
    baseUrl: string;
    baseSshUrl: string;
    owner: string;
    repo: string;
    branch: string;
}
export interface Params {
    git: Git.Command;
    protocol: "ssh" | "https";
    repoConfig: RepositoryConfig;
    workingDir: string;
}
export interface Storage {
    /**
     * Set up the target Git repository in your local directory.
     */
    setup: () => Promise<void>;
    /**
     * Make sure your git directory is clean.
     */
    isClean: () => Promise<boolean>;
    /**
     * Add the local changes to the stage.
     * (git add -A)
     */
    save: () => Git.Type;
    /**
     * Git commit.
     */
    commit: (message: string) => Git.Type;
    /**
     * Git push.
     */
    push: (branch?: string) => Git.Type;
    /**
     * Clear the working directory.
     */
    clear: () => void;
}
export declare const create: ({ git, repoConfig, protocol, workingDir }: Params) => Storage;
